==> ice-3.7.5.tgz: package/src/es5/Ice/Locator.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

//
// Copyright (c) ZeroC, Inc. All rights reserved.
//
//
// Ice version 3.7.5
//
// <auto-generated>
//
// Generated from file `Locator.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

/* eslint-disable */

/* jshint ignore: start */

/* slice2js browser-bundle-skip */
(function (module, require, exports) {
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
  var _ModuleRegistry = require("../Ice/ModuleRegistry").Ice._ModuleRegistry;

  var Ice = _ModuleRegistry.require(module, ["../Ice/Object", "../Ice/Value", "../Ice/ObjectPrx", "../Ice/Operation", "../Ice/Exception", "../Ice/Long", "../Ice/HashMap", "../Ice/HashUtil", "../Ice/ArrayUtil", "../Ice/StreamHelpers", "../Ice/Identity", "../Ice/Process"]).Ice;

  var Slice = Ice.Slice;
  /* slice2js browser-bundle-skip-end */

  /**
   * This exception is raised if an adapter cannot be found.
   *
   **/

  Ice.AdapterNotFoundException = /*#__PURE__*/function (_Ice$UserException) {
    _inherits(_class, _Ice$UserException);

    var _super = _createSuper(_class);

    function _class() {
      var _cause = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      _classCallCheck(this, _class);

      return _super.call(this, _cause);
    }

    _createClass(_class, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Ice.AdapterNotFoundException;
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Ice::AdapterNotFoundException";
      }
    }]);

    return _class;
  }(Ice.UserException);
  /**
   * This exception is raised if the replica group provided by the
   * server is invalid.
   *
   **/


  Ice.InvalidReplicaGroupIdException = /*#__PURE__*/function (_Ice$UserException2) {
    _inherits(_class2, _Ice$UserException2);

    var _super2 = _createSuper(_class2);

    function _class2() {
      var _cause = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      _classCallCheck(this, _class2);

      return _super2.call(this, _cause);
    }

    _createClass(_class2, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Ice.InvalidReplicaGroupIdException;
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Ice::InvalidReplicaGroupIdException";
      }
    }]);

    return _class2;
  }(Ice.UserException);
  /**
   * This exception is raised if a server tries to set endpoints for
   * an adapter that is already active.
   *
   **/


  Ice.AdapterAlreadyActiveException = /*#__PURE__*/function (_Ice$UserException3) {
    _inherits(_class3, _Ice$UserException3);

    var _super3 = _createSuper(_class3);

    function _class3() {
      var _cause = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      _classCallCheck(this, _class3);

      return _super3.call(this, _cause);
    }

    _createClass(_class3, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Ice.AdapterAlreadyActiveException;
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Ice::AdapterAlreadyActiveException";
      }
    }]);

    return _class3;
  }(Ice.UserException);
  /**
   * This exception is raised if an object cannot be found.
   *
   **/


  Ice.ObjectNotFoundException = /*#__PURE__*/function (_Ice$UserException4) {
    _inherits(_class4, _Ice$UserException4);

    var _super4 = _createSuper(_class4);

    function _class4() {
      var _cause = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      _classCallCheck(this, _class4);

      return _super4.call(this, _cause);
    }

    _createClass(_class4, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Ice.ObjectNotFoundException;
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Ice::ObjectNotFoundException";
      }
    }]);

    return _class4;
  }(Ice.UserException);
  /**
   * This exception is raised if a server cannot be found.
   *
   **/


  Ice.ServerNotFoundException = /*#__PURE__*/function (_Ice$UserException5) {
    _inherits(_class5, _Ice$UserException5);

    var _super5 = _createSuper(_class5);

    function _class5() {
      var _cause = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      _classCallCheck(this, _class5);

      return _super5.call(this, _cause);
    }

    _createClass(_class5, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Ice.ServerNotFoundException;
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Ice::ServerNotFoundException";
      }
    }]);

    return _class5;
  }(Ice.UserException);

  var iceC_Ice_Locator_ids = ["::Ice::Locator", "::Ice::Object"];
  /**
   * The Ice locator interface. This interface is used by clients to
   * lookup adapters and objects. It is also used by servers to get the
   * locator registry proxy.
   *
   * <p class="Note">The {@link Locator} interface is intended to be used by
   * Ice internals and by locator implementations. Regular user code
   * should not attempt to use any functionality of this interface
   * directly.
   *
   **/

  Ice.Locator = /*#__PURE__*/function (_Ice$Object) {
    _inherits(_class6, _Ice$Object);

    var _super6 = _createSuper(_class6);

    function _class6() {
      _classCallCheck(this, _class6);

      return _super6.apply(this, arguments);
    }

    return _class6;
  }(Ice.Object);

  Ice.LocatorPrx = /*#__PURE__*/function (_Ice$ObjectPrx) {
    _inherits(_class7, _Ice$ObjectPrx);

    var _super7 = _createSuper(_class7);

    function _class7() {
      _classCallCheck(this, _class7);

      return _super7.apply(this, arguments);
    }

    return _class7;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Ice.Locator, Ice.LocatorPrx, iceC_Ice_Locator_ids, 0, {
    "findObjectById": [, 2, 1,, [9], [[Ice.Identity]],, [Ice.ObjectNotFoundException],,],
    "findAdapterById": [, 2, 1,, [9], [[7]],, [Ice.AdapterNotFoundException],,],
    "getRegistry": [, 2, 1,, ["Ice.LocatorRegistryPrx"],,,,,]
  });
  var iceC_Ice_LocatorRegistry_ids = ["::Ice::LocatorRegistry", "::Ice::Object"];
  /**
   * The Ice locator registry interface. This interface is used by
   * servers to register adapter endpoints with the locator.
   *
   * <p class="Note"> The {@link LocatorRegistry} interface is intended to be used
   * by Ice internals and by locator implementations. Regular user
   * code should not attempt to use any functionality of this interface
   * directly.
   *
   **/

  Ice.LocatorRegistry = /*#__PURE__*/function (_Ice$Object2) {
    _inherits(_class8, _Ice$Object2);

    var _super8 = _createSuper(_class8);

    function _class8() {
      _classCallCheck(this, _class8);

      return _super8.apply(this, arguments);
    }

    return _class8;
  }(Ice.Object);

  Ice.LocatorRegistryPrx = /*#__PURE__*/function (_Ice$ObjectPrx2) {
    _inherits(_class9, _Ice$ObjectPrx2);

    var _super9 = _createSuper(_class9);

    function _class9() {
      _classCallCheck(this, _class9);

      return _super9.apply(this, arguments);
    }

    return _class9;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Ice.LocatorRegistry, Ice.LocatorRegistryPrx, iceC_Ice_LocatorRegistry_ids, 0, {
    "setAdapterDirectProxy": [, 2, 2,,, [[7], [9]],, [Ice.AdapterAlreadyActiveException, Ice.AdapterNotFoundException],,],
    "setReplicatedAdapterDirectProxy": [, 2, 2,,, [[7], [7], [9]],, [Ice.AdapterAlreadyActiveException, Ice.AdapterNotFoundException, Ice.InvalidReplicaGroupIdException],,],
    "setServerProcessProxy": [, 2, 2,,, [[7], ["Ice.ProcessPrx"]],, [Ice.ServerNotFoundException],,]
  });
  var iceC_Ice_LocatorFinder_ids = ["::Ice::LocatorFinder", "::Ice::Object"];
  /**
   * This inferface should be implemented by services implementing the
   * Ice::Locator interface. It should be advertised through an Ice
   * object with the identity `Ice/LocatorFinder'. This allows clients
   * to retrieve the locator proxy with just the endpoint information of
   * the service.
   *
   **/

  Ice.LocatorFinder = /*#__PURE__*/function (_Ice$Object3) {
    _inherits(_class10, _Ice$Object3);

    var _super10 = _createSuper(_class10);

    function _class10() {
      _classCallCheck(this, _class10);

      return _super10.apply(this, arguments);
    }

    return _class10;
  }(Ice.Object);

  Ice.LocatorFinderPrx = /*#__PURE__*/function (_Ice$ObjectPrx3) {
    _inherits(_class11, _Ice$ObjectPrx3);

    var _super11 = _createSuper(_class11);

    function _class11() {
      _classCallCheck(this, _class11);

      return _super11.apply(this, arguments);
    }

    return _class11;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Ice.LocatorFinder, Ice.LocatorFinderPrx, iceC_Ice_LocatorFinder_ids, 0, {
    "getLocator": [,,,, ["Ice.LocatorPrx"],,,,,]
  });
  /* slice2js browser-bundle-skip */

  exports.Ice = Ice;
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
})(typeof global !== "undefined" && typeof global.process !== "undefined" ? module : undefined, typeof global !== "undefined" && typeof global.process !== "undefined" ? require : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self.Ice._require : window.Ice._require, typeof global !== "undefined" && typeof global.process !== "undefined" ? exports : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self : window);
/* slice2js browser-bundle-skip-end */

==> ice-3.7.70.tgz: package/src/es5/Ice/Locator.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

//
// Copyright (c) ZeroC, Inc. All rights reserved.
//
//
// Ice version 3.7.7
//
// <auto-generated>
//
// Generated from file `Locator.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

/* eslint-disable */

/* jshint ignore: start */

/* slice2js browser-bundle-skip */
(function (module, require, exports) {
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
  var _ModuleRegistry = require("../Ice/ModuleRegistry").Ice._ModuleRegistry;

  var Ice = _ModuleRegistry.require(module, ["../Ice/Object", "../Ice/Value", "../Ice/ObjectPrx", "../Ice/Operation", "../Ice/Exception", "../Ice/Long", "../Ice/HashMap", "../Ice/HashUtil", "../Ice/ArrayUtil", "../Ice/StreamHelpers", "../Ice/Identity", "../Ice/Process"]).Ice;

  var Slice = Ice.Slice;
  /* slice2js browser-bundle-skip-end */

  /**
   * This exception is raised if an adapter cannot be found.
   *
   **/

  Ice.AdapterNotFoundException = /*#__PURE__*/function (_Ice$UserException) {
    _inherits(_class, _Ice$UserException);

    var _super = _createSuper(_class);

    function _class() {
      var _cause = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      _classCallCheck(this, _class);

      return _super.call(this, _cause);
    }

    _createClass(_class, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Ice.AdapterNotFoundException;
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Ice::AdapterNotFoundException";
      }
    }]);

    return _class;
  }(Ice.UserException);
  /**
   * This exception is raised if the replica group provided by the
   * server is invalid.
   *
   **/


  Ice.InvalidReplicaGroupIdException = /*#__PURE__*/function (_Ice$UserException2) {
    _inherits(_class2, _Ice$UserException2);

    var _super2 = _createSuper(_class2);

    function _class2() {
      var _cause = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      _classCallCheck(this, _class2);

      return _super2.call(this, _cause);
    }

    _createClass(_class2, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Ice.InvalidReplicaGroupIdException;
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Ice::InvalidReplicaGroupIdException";
      }
    }]);

    return _class2;
  }(Ice.UserException);
  /**
   * This exception is raised if a server tries to set endpoints for
   * an adapter that is already active.
   *
   **/


  Ice.AdapterAlreadyActiveException = /*#__PURE__*/function (_Ice$UserException3) {
    _inherits(_class3, _Ice$UserException3);

    var _super3 = _createSuper(_class3);

    function _class3() {
      var _cause = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      _classCallCheck(this, _class3);

      return _super3.call(this, _cause);
    }

    _createClass(_class3, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Ice.AdapterAlreadyActiveException;
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Ice::AdapterAlreadyActiveException";
      }
    }]);

    return _class3;
  }(Ice.UserException);
  /**
   * This exception is raised if an object cannot be found.
   *
   **/


  Ice.ObjectNotFoundException = /*#__PURE__*/function (_Ice$UserException4) {
    _inherits(_class4, _Ice$UserException4);

    var _super4 = _createSuper(_class4);

    function _class4() {
      var _cause = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      _classCallCheck(this, _class4);

      return _super4.call(this, _cause);
    }

    _createClass(_class4, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Ice.ObjectNotFoundException;
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Ice::ObjectNotFoundException";
      }
    }]);

    return _class4;
  }(Ice.UserException);
  /**
   * This exception is raised if a server cannot be found.
   *
   **/


  Ice.ServerNotFoundException = /*#__PURE__*/function (_Ice$UserException5) {
    _inherits(_class5, _Ice$UserException5);

    var _super5 = _createSuper(_class5);

    function _class5() {
      var _cause = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      _classCallCheck(this, _class5);

      return _super5.call(this, _cause);
    }

    _createClass(_class5, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Ice.ServerNotFoundException;
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Ice::ServerNotFoundException";
      }
    }]);

    return _class5;
  }(Ice.UserException);

  var iceC_Ice_Locator_ids = ["::Ice::Locator", "::Ice::Object"];
  /**
   * The Ice locator interface. This interface is used by clients to
   * lookup adapters and objects. It is also used by servers to get the
   * locator registry proxy.
   *
   * <p class="Note">The {@link Locator} interface is intended to be used by
   * Ice internals and by locator implementations. Regular user code
   * should not attempt to use any functionality of this interface
   * directly.
   *
   **/

  Ice.Locator = /*#__PURE__*/function (_Ice$Object) {
    _inherits(_class6, _Ice$Object);

    var _super6 = _createSuper(_class6);

    function _class6() {
      _classCallCheck(this, _class6);

      return _super6.apply(this, arguments);
    }

    return _class6;
  }(Ice.Object);

  Ice.LocatorPrx = /*#__PURE__*/function (_Ice$ObjectPrx) {
    _inherits(_class7, _Ice$ObjectPrx);

    var _super7 = _createSuper(_class7);

    function _class7() {
      _classCallCheck(this, _class7);

      return _super7.apply(this, arguments);
    }

    return _class7;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Ice.Locator, Ice.LocatorPrx, iceC_Ice_Locator_ids, 0, {
    "findObjectById": [, 2, 1,, [9], [[Ice.Identity]],, [Ice.ObjectNotFoundException],,],
    "findAdapterById": [, 2, 1,, [9], [[7]],, [Ice.AdapterNotFoundException],,],
    "getRegistry": [, 2, 1,, ["Ice.LocatorRegistryPrx"],,,,,]
  });
  var iceC_Ice_LocatorRegistry_ids = ["::Ice::LocatorRegistry", "::Ice::Object"];
  /**
   * The Ice locator registry interface. This interface is used by
   * servers to register adapter endpoints with the locator.
   *
   * <p class="Note"> The {@link LocatorRegistry} interface is intended to be used
   * by Ice internals and by locator implementations. Regular user
   * code should not attempt to use any functionality of this interface
   * directly.
   *
   **/

  Ice.LocatorRegistry = /*#__PURE__*/function (_Ice$Object2) {
    _inherits(_class8, _Ice$Object2);

    var _super8 = _createSuper(_class8);

    function _class8() {
      _classCallCheck(this, _class8);

      return _super8.apply(this, arguments);
    }

    return _class8;
  }(Ice.Object);

  Ice.LocatorRegistryPrx = /*#__PURE__*/function (_Ice$ObjectPrx2) {
    _inherits(_class9, _Ice$ObjectPrx2);

    var _super9 = _createSuper(_class9);

    function _class9() {
      _classCallCheck(this, _class9);

      return _super9.apply(this, arguments);
    }

    return _class9;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Ice.LocatorRegistry, Ice.LocatorRegistryPrx, iceC_Ice_LocatorRegistry_ids, 0, {
    "setAdapterDirectProxy": [, 2, 2,,, [[7], [9]],, [Ice.AdapterAlreadyActiveException, Ice.AdapterNotFoundException],,],
    "setReplicatedAdapterDirectProxy": [, 2, 2,,, [[7], [7], [9]],, [Ice.AdapterAlreadyActiveException, Ice.AdapterNotFoundException, Ice.InvalidReplicaGroupIdException],,],
    "setServerProcessProxy": [, 2, 2,,, [[7], ["Ice.ProcessPrx"]],, [Ice.ServerNotFoundException],,]
  });
  var iceC_Ice_LocatorFinder_ids = ["::Ice::LocatorFinder", "::Ice::Object"];
  /**
   * This inferface should be implemented by services implementing the
   * Ice::Locator interface. It should be advertised through an Ice
   * object with the identity `Ice/LocatorFinder'. This allows clients
   * to retrieve the locator proxy with just the endpoint information of
   * the service.
   *
   **/

  Ice.LocatorFinder = /*#__PURE__*/function (_Ice$Object3) {
    _inherits(_class10, _Ice$Object3);

    var _super10 = _createSuper(_class10);

    function _class10() {
      _classCallCheck(this, _class10);

      return _super10.apply(this, arguments);
    }

    return _class10;
  }(Ice.Object);

  Ice.LocatorFinderPrx = /*#__PURE__*/function (_Ice$ObjectPrx3) {
    _inherits(_class11, _Ice$ObjectPrx3);

    var _super11 = _createSuper(_class11);

    function _class11() {
      _classCallCheck(this, _class11);

      return _super11.apply(this, arguments);
    }

    return _class11;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Ice.LocatorFinder, Ice.LocatorFinderPrx, iceC_Ice_LocatorFinder_ids, 0, {
    "getLocator": [,,,, ["Ice.LocatorPrx"],,,,,]
  });
  /* slice2js browser-bundle-skip */

  exports.Ice = Ice;
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
})(typeof global !== "undefined" && typeof global.process !== "undefined" ? module : undefined, typeof global !== "undefined" && typeof global.process !== "undefined" ? require : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self.Ice._require : window.Ice._require, typeof global !== "undefined" && typeof global.process !== "undefined" ? exports : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self : window);
/* slice2js browser-bundle-skip-end */
